/**
 * Copyright 2009-2012 Serli
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.plan.fetcher.test;

import static org.testng.Assert.assertTrue;

import java.io.File;
import java.io.FileOutputStream;
import java.net.URL;

import org.ow2.util.plan.bindings.deploymentplan.url.UrlDeployment;
import org.ow2.util.plan.bindings.repository.Repository;
import org.ow2.util.plan.bindings.repository.RepositoryKind;
import org.ow2.util.plan.fetcher.api.IResourceFetcher;
import org.ow2.util.plan.fetcher.api.IResourceFetcherFactoryManager;
import org.ow2.util.plan.fetcher.impl.ResourceFetcherFactoryManagerImpl;
import org.ow2.util.plan.fetcher.impl.url.UrlResourceFetcherFactory;
import org.ow2.util.plan.repository.impl.DefaultRepositoryManager;
import org.testng.annotations.Test;

/**
 * Test class for the deployment plan deployer.
 * @author mleduque
 */
public class URLTest {

    private final static String FILE_PROTOCOL = "file";

    private final static String TEST_LOCATION = "/target/test-classes/";

    private Repository repository = new Repository();

    private UrlDeployment deployment = new UrlDeployment();

    private IResourceFetcherFactoryManager factoryManager = null;

    private UrlResourceFetcherFactory urlFactory = null;

    private String testLocation = null;

    @Test
    public void prepareData() throws Exception {
        testLocation = System.getProperty("user.dir") + TEST_LOCATION;

        repository.setType(RepositoryKind.URL);
        URL repositoryUrl = new URL(FILE_PROTOCOL, "", testLocation);
        repository.setUrl(repositoryUrl.toExternalForm());
        repository.setId("url-repository");
        DefaultRepositoryManager.getInstance().addRepository(repository);

        deployment.setId("deployment1");
        deployment.setResource("resource");

        File resourceFile = new File(testLocation, "resource");
        if (resourceFile.exists()) {
            if (!resourceFile.delete()) {
                throw new Exception("Could not delete the resource file");
            }
        }
        FileOutputStream stream = new FileOutputStream(resourceFile);
        stream.close();
    }

    @Test(dependsOnMethods = {"prepareData"})
    public void prepareFetcher() throws Exception {
        urlFactory = new UrlResourceFetcherFactory();
        urlFactory.setRepositoryManager(DefaultRepositoryManager.getInstance());
        urlFactory.setLocalRepositoriesBaseDir(new File(testLocation, "result/"));
        factoryManager = new ResourceFetcherFactoryManagerImpl();
        factoryManager.addResourceFetcherFactory(urlFactory);
    }

    // @Test(dependsOnMethods={"prepareFetcher"})
    public void testFetcher() throws Exception {
        IResourceFetcher fetcher = factoryManager.getResourceFetcher(deployment);
        fetcher.resolve();
        File file = fetcher.getResource();
        assertTrue(file.exists());
    }

}
